@@ -1,11 +1,12 @@
-try:
+try :
     import matplotlib.pyplot as plt
     from PIL import Image
     from PIL import ImageFont
     from PIL import ImageDraw
     import numpy as np
     import cv2
-except ImportError as e:
+except ImportError as e :
     import os
-    os.system("python3 -m pip install matplotlib numpy opencv-python numba")
-    raise e
\ No newline at end of file
+
+    os.system("python3 -m pip install matplotlib numpy opencv-python Pillow")
+    raise e
